@@ -312,7 +312,7 @@ static Window openSolidWindow(int argc, char** argv,
 		     &xsh.x, &xsh.y, &xsh.width, &xsh.height);
     xsh.min_width = xsh.max_width = xsh.width;
     xsh.min_height = xsh.max_height = xsh.height;
-    xsh.flags = (PPosition | PSize | PMinSize | PMaxSize);
+    xsh.flags = (PSize | PMinSize | PMaxSize);
     
     win = XCreateSimpleWindow(disp, DefaultRootWindow(disp),
 			      xsh.x, xsh.y, xsh.width, xsh.height,
@@ -430,7 +430,7 @@ void initAppl(int argc, char** argv)
     
     /* open a window */
     mywin = openSolidWindow(argc, argv, mygeom,
-			    ExposureMask | KeyPressMask | ButtonPressMask,
+			    ExposureMask | KeyPressMask,
 			    &myxwa);
 
     /* create a background image buffer */
